@@ -6,7 +6,7 @@ from .skeleton import (
 from .mesh import (
   MeshTask, MeshManifestPrefixTask, 
   MeshManifestFilesystemTask,
-  GrapheneMeshTask, MeshSpatialIndex,
+  GrapheneMeshTask,
   MultiResUnshardedMeshMergeTask,
   MultiResShardedMeshMergeTask,
   MultiResShardedFromUnshardedMeshMergeTask,
@@ -19,4 +19,5 @@ from .image import (
   LuminanceLevelsTask, ContrastNormalizationTask,
   MaskAffinitymapTask, InferenceTask, BlackoutTask,
   TouchTask, ImageShardTransferTask, ImageShardDownsampleTask
-)
\ No newline at end of file
+)
+from .spatial_index import SpatialIndexTask
\ No newline at end of file
