@@ -56,7 +56,7 @@ class Tuple2(click.ParamType):
 
 @click.group()
 @click.option("-p", "--parallel", default=1, help="Run with this number of parallel processes. If 0, use number of cores.")
-@click.version_option(version="4.0.0")
+@click.version_option(version="4.1.0")
 @click.pass_context
 def main(ctx, parallel):
   """
@@ -209,7 +209,7 @@ def downsample(
 @click.option('--sparse', is_flag=True, default=False, help="Don't count black pixels in mode or average calculations. For images, eliminates edge ghosting in 2x2x2 downsample. For segmentation, prevents small objects from disappearing at high mip levels.")
 @click.option('--shape', type=Tuple3(), default=(2048, 2048, 64), help="(overrides --memory) Set the task shape in voxels. This also determines how many downsamples you get. e.g. 2048,2048,64")
 @click.option('--chunk-size', type=Tuple3(), default=None, help="Chunk size of destination layer. e.g. 128,128,64")
-@click.option('--compress', default="gzip", help="Set the image compression scheme. Options: 'gzip', 'br'", show_default=True)
+@click.option('--compress', default="gzip", help="Set the image compression scheme. Options: 'none', 'gzip', 'br'", show_default=True)
 @click.option('--volumetric', is_flag=True, default=False, help="Use 2x2x2 downsampling.")
 @click.option('--delete-bg', is_flag=True, default=False, help="Issue a delete instead of uploading a background tile. This is helpful on systems that don't like tiny files.")
 @click.option('--bg-color', default=0, help="Determines which color is regarded as background.", show_default=True)
@@ -254,7 +254,7 @@ def xfer(
   if volumetric:
   	factor = (2,2,2)
 
-  if compress and compress.lower() == "false":
+  if compress and compress.lower() in ("none", "false"):
     compress = False
 
   if sharded:
@@ -388,12 +388,13 @@ def equalize(
 @click.option('--lease-sec', default=LEASE_SECONDS, help=f"Seconds to lease a task for.", type=int, show_default=True)
 @click.option('--tally/--no-tally', is_flag=True, default=True, help="Tally completed fq tasks. Does not apply to SQS.", show_default=True)
 @click.option('--min-sec', default=-1, help='Execute for at least this many seconds and quit after the last task finishes. Special values: (0) Run at most a single task. (-1) Loop forever (default).', type=float)
+@click.option('-q', '--quiet', is_flag=True, default=False, help='Suppress task status messages.', show_default=True)
 @click.option('-x', '--exit-on-empty', is_flag=True, default=False, help="Exit immediately when the queue is empty. Not reliable for SQS as measurements are approximate.", show_default=True)
 @click.pass_context
 def execute(
   ctx, queue, aws_region,
   lease_sec, tally, min_sec,
-  exit_on_empty
+  exit_on_empty, quiet
 ):
   """Execute igneous tasks from a queue.
 
@@ -404,7 +405,7 @@ def execute(
   See https://github.com/seung-lab/python-task-queue
   """
   parallel = int(ctx.obj.get("parallel", 1))
-  args = (queue, aws_region, lease_sec, tally, min_sec, exit_on_empty)
+  args = (queue, aws_region, lease_sec, tally, min_sec, exit_on_empty, quiet)
 
   if parallel == 1:
     execute_helper(*args)
@@ -423,7 +424,8 @@ def execute(
 
 def execute_helper(
   queue, aws_region, lease_sec, 
-  tally, min_sec, exit_on_empty
+  tally, min_sec, exit_on_empty,
+  quiet
 ):
   tq = TaskQueue(normalize_path(queue), region_name=aws_region)
 
@@ -438,7 +440,7 @@ def execute_helper(
   if min_sec != 0:
     tq.poll(
       lease_seconds=lease_sec,
-      verbose=True,
+      verbose=(not quiet),
       tally=tally,
       stop_fn=stop_after_elapsed_time,
     )
@@ -580,13 +582,14 @@ def mesh_merge(ctx, path, queue, magnitude, dir):
 @click.option('--compress-level', default=7, help="Draco compression level.", type=int, show_default=True)
 @click.option('--shard-index-bytes', default=2**13, help="Size in bytes to make the shard index.", type=int, show_default=True)
 @click.option('--minishard-index-bytes', default=2**15, help="Size in bytes to make the minishard index.", type=int, show_default=True)
+@click.option('--min-shards', default=1, help="Minimum number of shards to generate. Excess shards can make it easier to parallelize the merge process.", type=int, show_default=True)
 @click.option('--minishard-index-encoding', default="gzip", help="Minishard indices can be compressed. gzip or raw.", show_default=True)
 @click.option('--spatial-index-db', default=None, help="CloudVolume generated SQL database for spatial index.", show_default=True)
 @click.pass_context
 def mesh_sharded_merge(
   ctx, path, queue, 
   vqb, compress_level,
-  shard_index_bytes, minishard_index_bytes,
+  shard_index_bytes, minishard_index_bytes, min_shards,
   minishard_index_encoding, spatial_index_db
 ):
   """
@@ -609,6 +612,7 @@ def mesh_sharded_merge(
     shard_index_bytes=shard_index_bytes,
     minishard_index_bytes=minishard_index_bytes,
     minishard_index_encoding=minishard_index_encoding,
+    min_shards=min_shards,
     spatial_index_db=spatial_index_db,
   )
 
@@ -814,6 +818,7 @@ def skeleton_merge(
 @click.option('--tick-threshold', default=0, help="Remove small \"ticks\", or branches from the main skeleton one at a time from smallest to largest. Branches larger than this are preserved. Default: no elimination", type=float)
 @click.option('--shard-index-bytes', default=2**13, help="Size in bytes to make the shard index.", type=int, show_default=True)
 @click.option('--minishard-index-bytes', default=2**15, help="Size in bytes to make the minishard index.", type=int, show_default=True)
+@click.option('--min-shards', default=1, help="Minimum number of shards to generate. Excess shards can make it easier to parallelize the merge process.", type=int, show_default=True)
 @click.option('--minishard-index-encoding', default="gzip", help="Minishard indices can be compressed. gzip or raw. Default: gzip")
 @click.option('--data-encoding', default="gzip", help="Shard data can be compressed. gzip or raw. Default: gzip")
 @click.option('--spatial-index-db', default=None, help="CloudVolume generated SQL database for spatial index.", show_default=True)
@@ -822,7 +827,7 @@ def skeleton_sharded_merge(
   ctx, path, queue, 
   min_cable_length, max_cable_length, 
   tick_threshold, 
-  shard_index_bytes, minishard_index_bytes,
+  shard_index_bytes, minishard_index_bytes, min_shards,
   minishard_index_encoding, data_encoding,
   spatial_index_db
 ):
@@ -838,6 +843,7 @@ def skeleton_sharded_merge(
   The shard and minishard index default sizes are set to
   accomodate efficient access for a 100 Mbps connection.
   """
+  path = cloudfiles.paths.normalize(path)
   tasks = tc.create_sharded_skeleton_merge_tasks(
     path, 
     dust_threshold=min_cable_length,
@@ -845,6 +851,7 @@ def skeleton_sharded_merge(
     tick_threshold=tick_threshold,
     shard_index_bytes=shard_index_bytes,
     minishard_index_bytes=minishard_index_bytes,
+    min_shards=min_shards,
     minishard_index_encoding=minishard_index_encoding, 
     data_encoding=data_encoding,
     spatial_index_db=spatial_index_db,
